/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-02-12  Gelin   Initially created.
 *  2006-04-06  Gelin   "Beanize" class
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;

import javax.swing.AbstractAction;
import java.awt.event.ActionEvent;

/**
 *  This class provides basic action for game. Action of this class or subclass
 *  takes reference to the game and saves it into internal property.
 */
public abstract class AGameAction extends AbstractAction {

    /** The key, used to store the game reference for which action belongs. */
    public static final String GAME = "Javatris";

    /**
     *  Creates action for specified game.
     *  @param  aoGame  game reference
     *  @param  asCommand   action command key
     */
    public AGameAction(Javatris aoGame, String asCommand) {
        this(asCommand);
        setGame(aoGame);
    }

    /**
     *  Creates action with specified command.
     *  You must specify game for this action by {@link #setGame} method.
     *  @param  asCommand   action command key
     */
    public AGameAction(String asCommand) {
        super();
        putValue(ACTION_COMMAND_KEY, asCommand);
    }

    /**
     *  Sets game reference for this action. Convenience method.
     */
    public void setGame(Javatris aoGame) {
        putValue(GAME, aoGame);
    }

    /**
     *  Gets game reference for this action. Convenience method.
     */
    public Javatris getGame() {
        return (Javatris)getValue(GAME);
    }

    /**
     *  This method is called then action is performed.
     */
    public abstract void actionPerformed(ActionEvent aoEvent);

}