/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-02-12  Gelin   Initially created.
 *  2006-04-06  Gelin   "Beanize" class
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;

import java.awt.event.ActionEvent;
import javax.swing.KeyStroke;
import javax.swing.JComponent;
import javax.swing.InputMap;
import javax.swing.ActionMap;

/**
 *  This class provides action which must be called by key pressing.
 */
public abstract class AKeyAction extends AGameAction {

    /** The key for saving many accelerator keys */
    public static final String ACCELERATOR_KEY_ARRAY = "AcceleratorKeyArray";

    /**
     *  Creates action from game reference and accelerators array.
     *  @param  aoGame  game reference
     *  @param  asCommand   name of the action command
     *  @param  aoAccelerators  array of accelerator keys, first element of this array becomes
     *                          default <code>ACCELERATOR_KEY</code>
     */
    public AKeyAction(Javatris aoGame, String asCommand, KeyStroke[] aoAccelerators) {
        super(asCommand);
        setGame(aoGame);
        setAccelerators(aoAccelerators);
    }

    /**
     *  Creates action with specified command name.
     *  You must set game reference and array of accelerator key by appropriate set methods.
     *  @param  asCommand   name of the action command
     */
    public AKeyAction(String asCommand) {
        super(asCommand);
    }

    /**
     *  Sets array of accelerator keys. Convenience method.
     */
    public void setAccelerators(KeyStroke[] aoAccelerators) {
        if (aoAccelerators.length > 0) {
            putValue(ACCELERATOR_KEY, aoAccelerators[0]);
        }
        putValue(ACCELERATOR_KEY_ARRAY, aoAccelerators);
    }

    /**
     *  Gets array of accelerator keys. Convenience method
     */
    public KeyStroke[] getAccelerators() {
        return (KeyStroke[])getValue(ACCELERATOR_KEY_ARRAY);
    }

    /**
     *  Registers this action for specified component. Puts every accelerators key
     *  into component's {@link InputMap} and registers them to this action into
     *  component's {@link ActionMap}.
     *  @param  aoComponent  component for which action will be registered
     *  @see    InputMap
     *  @see    ActionMap
     *  @see    JComponent#WHEN_IN_FOCUSED_WINDOW
     */
    public void registerFor(JComponent aoComponent) {
        int iMapType = JComponent.WHEN_IN_FOCUSED_WINDOW;
        //int iMapType = JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT;
        //int iMapType = JComponent.WHEN_FOCUSED;
        InputMap oMap = aoComponent.getInputMap(iMapType);
        KeyStroke[] oKeys = (KeyStroke[])getValue(ACCELERATOR_KEY_ARRAY);
        // register keys
        for (int i = 0; i < oKeys.length; i++) {
            oMap.put(oKeys[i], getValue(ACTION_COMMAND_KEY));
        }
        // register action
        aoComponent.getActionMap().put(getValue(ACTION_COMMAND_KEY), this);
    }

}