/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created.
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.ui.IToolBarModes;

import javax.swing.KeyStroke;
import java.awt.event.ActionEvent;

/**
 *  This class provides action for tool bar toggle buttons.
 *  It contains properties for selected button status.
 */
public abstract class AToggleToolBarAction extends AToolBarAction implements IToolBarModes {

    /** The key, used to store pressed button status. */
    public static final String SELECTED = "Selected";

    /**
     *  Creates action from all parameters.
     *  Initially button is not selected.
     *  @param  aoGame  game reference
     *  @param  asCommand   action command key
     *  @param  aoAccelerators  array of accelerator keys, first element of this array becomes
     *                          default <code>ACCELERATOR_KEY</code>
     *  @param  asText      key of message with button's text
     *  @param  asIcon      key of image
     *  @param  asToolTip   key of message with tooltip text
     *  @param  aiShowMode  current show mode for this button
     *  @param  abShowText  <code>true</code> if button must show text
     *                      in <code>SHOW_SELECTIVE</code> mode
     */
    public AToggleToolBarAction(Javatris aoGame, String asCommand,
            KeyStroke[] aoAccelerators,
            String asText, String asIcon, String asToolTip,
            int aiShowMode, boolean abShowText) {
        super(asCommand);
        setGame(aoGame);
        setAccelerators(aoAccelerators);
        setText(asText);
        setIcon(asIcon);
        setToolTipText(asToolTip);
        setToolBarMode(aiShowMode);
        setShowText(abShowText);
    }

    /**
     *  Creates action from minimum set of parameters.
     *  Other parameters must be set by appropriate set methods.
     *  @param  asCommand   action command key
     */
    public AToggleToolBarAction(String asCommand) {
        super(asCommand);
    }

    /**
     *  Sets selected status for button.
     *  @param  abSelected  true if button must be looked selected
     */
    public void setSelected(boolean abSelected) {
        putValue(SELECTED, new Boolean(abSelected));
    }

    /**
     *  Gets current selected button status.
     *  @return     true if button must be looked selected
     */
    public boolean isSelected() {
        Boolean oSelected = (Boolean)(getValue(SELECTED));
        return oSelected != null ? oSelected.booleanValue() : false;
    }

    /**
     *  This method is called then action is performed.
     */
    public abstract void actionPerformed(ActionEvent aoEvent);

}