/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created.
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.ui.CommonDialog;
import ru.gelin.games.javatris.ui.AboutContentPane;
import ru.gelin.games.javatris.util.Messages;

import javax.swing.KeyStroke;
import javax.swing.JDialog;
import java.awt.event.ActionEvent;

/**
 *  This class provides action for show about toolbar button.
 */
public class AboutAction extends AToolBarAction implements IActionNames {

    private static final KeyStroke[] ACCELERATORS = {
            KeyStroke.getKeyStroke("F1"),   //F1
            KeyStroke.getKeyStroke("ctrl H"),   //Ctrl+H
    };

    /**
     *  Default constructor.
     *  @param  aoGame  game reference
     */
    public AboutAction(Javatris aoGame) {
        super(ABOUT_ACTION);
        setGame(aoGame);
        setAccelerators(ACCELERATORS);
        setText("about_button.text");
        setIcon("about_button.icon");
        setToolTipText("about_button.tooltip");
        setToolBarMode(SHOW_SELECTIVE);
        setShowText(false);
    }

    /**
     *  This method is called then user press about toolbar button.
     */
    public void actionPerformed(ActionEvent aoEvent) {
        Javatris oGame = getGame();
        oGame.pauseAuto();
        //open about dialog
        JDialog oDialog = new CommonDialog(Messages.getInstance().get("about_dialog.title"),
                new AboutContentPane(oGame));
        oDialog.show();
    }

}