/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-02-19  Gelin   Initially created.
 *  2006-04-06  Gelin   Switched to use convenience methods
 *  2006-08-26  Gelin   Bugfix #3
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;

import java.awt.event.ActionEvent;
import javax.swing.KeyStroke;

/**
 *  This action calls then user press down arrow key to drop the block.
 */
public class DropAction extends AKeyAction implements IActionNames {

    private static final KeyStroke[] ACCELERATORS = {
            KeyStroke.getKeyStroke("DOWN"),     //up arrow key
            KeyStroke.getKeyStroke("KP_DOWN"),  //up arrow key on NumPad
            KeyStroke.getKeyStroke("SPACE"),    //space
    };

    /**
     *  Default constructor. Creates action for specified game.
     *  @param  aoGame  game reference
     */
    public DropAction(Javatris aoGame) {
        super(DROP_ACTION);
        setGame(aoGame);
        setAccelerators(ACCELERATORS);
    }

    /**
     *  This method is called then block must be rotated.
     */
    public void actionPerformed(ActionEvent aoEvent) {
        Javatris oGame = getGame();
        if (!oGame.isPaused() && !oGame.isBlockStopped()) {
            oGame.dropBlock();
        }
    }

}