/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-02-12  Gelin   Initially created.
 *  2006-04-06  Gelin   Switched to use convenience method
 *  2006-08-26  Gelin   Bugfix #3
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;

import java.awt.event.ActionEvent;
import javax.swing.KeyStroke;

/**
 *  This action calls then user press right arrow key for moving block right.
 */
public class MoveRightAction extends AKeyAction implements IActionNames {

    private static final KeyStroke[] ACCELERATORS = {
            KeyStroke.getKeyStroke("RIGHT"),     //right arrow key
            KeyStroke.getKeyStroke("KP_RIGHT"),  //right arrow key on NumPad
    };

    /**
     *  Default constructor. Creates action for specified game.
     *  @param  aoGame  game reference
     */
    public MoveRightAction(Javatris aoGame) {
        super(MOVE_RIGHT_ACTION);
        setGame(aoGame);
        setAccelerators(ACCELERATORS);
    }

    /**
     *  This method is called then block must be moved right.
     */
    public void actionPerformed(ActionEvent aoEvent) {
        Javatris oGame = getGame();
        if (!oGame.isPaused() && !oGame.isBlockStopped()) {
            oGame.getGlass().moveRight();
        }
    }

}