/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created.
 */

package ru.gelin.games.javatris.actions;

import ru.gelin.games.javatris.game.Javatris;

import javax.swing.KeyStroke;
import java.awt.event.ActionEvent;

/**
 *  This class provides action for pause game toolbar button.
 */
public class PauseGameAction extends AToggleToolBarAction implements IActionNames {

    private static final KeyStroke[] ACCELERATORS = {
            KeyStroke.getKeyStroke("F5"),   //F5
            KeyStroke.getKeyStroke("ctrl P"),   //Ctrl+P
    };

    /**
     *  Default constructor.
     *  @param  aoGame  game reference
     */
    public PauseGameAction(Javatris aoGame) {
        super(PAUSE_GAME_ACTION);
        setGame(aoGame);
        setAccelerators(ACCELERATORS);
        setText("pause_button.text");
        setIcon("pause_button.icon");
        setToolTipText("pause_button.tooltip");
        setToolBarMode(SHOW_SELECTIVE);
        setShowText(false);
    }

    /**
     *  This method is called then user press new game toolbar button.
     */
    public void actionPerformed(ActionEvent aoEvent) {
        Javatris oGame = getGame();
        if (oGame.isPaused()) {
            oGame.resumeManual();
            setSelected(false);
        } else {
            oGame.pauseManual();
            setSelected(true);
        }
    }

}