/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-25  Gelin   Initially created
 */

package ru.gelin.games.javatris.game;

import ru.gelin.games.javatris.ui.IColorTableModel;
import ru.gelin.games.javatris.ui.IColorTableListener;
import ru.gelin.games.javatris.ui.ColorTableEvent;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;
import java.awt.Color;

/**
 *  Abstract implementation of {@link IColorTableModel}, provides methods for
 *  operation with listeners.
 */
public abstract class AColorTableModel implements IColorTableModel {

    /** list of listeners */
    protected List moListeners;

    /**
     *  Constructor.
     */
    public AColorTableModel() {
        moListeners = new ArrayList();
    }

    /**
     *  Returns color contained in specified cell.
     */
    public Color getColor(int aiX, int aiY) {
        if (((aiX + aiY) % 2) == 0) {
            return Color.BLACK;
        } else {
            return Color.WHITE;
        }
    }

    public abstract int getWidth();

    public abstract int getHeight();

    public abstract int getPreferredCellSize();

    public abstract int getMinimumCellSize();

    public abstract int getMaximumCellSize();

    public void addColorTableListener(IColorTableListener aoListener) {
        moListeners.add(aoListener);
    }

    public void removeColorTableListener(IColorTableListener aoListener) {
        moListeners.remove(aoListener);
    }

    /**
     *  Sends event to every listeners.
     *
     *  @param  aoEvent event to be sent
     */
    protected void fireColorTableEvent(ColorTableEvent aoEvent) {
        Iterator i = moListeners.iterator();
        while (i.hasNext()) {
            IColorTableListener oListener =
                    (IColorTableListener)i.next();
            oListener.colorTableChanged(aoEvent);
        }
    }

}
