/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-01-22  Gelin   Initially created
 */

package ru.gelin.games.javatris.game;

import ru.gelin.games.javatris.ui.ILabelModel;
import ru.gelin.games.javatris.ui.ILabelListener;
import ru.gelin.games.javatris.ui.LabelEvent;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

/**
 *  Abstract implementation of {@link ILabelModel}, provides methods for
 *  operation with listeners.
 */
public abstract class ALabelModel implements ILabelModel {

    /** list of listeners */
    protected List moListeners;

    /**
     *  Constructor.
     */
    public ALabelModel() {
        moListeners = new ArrayList();
    }

    public abstract String getText();

    public abstract int getHorizontalAlignment();

    public void addLabelListener(ILabelListener aoListener) {
        moListeners.add(aoListener);
    }

    public void removeLabelListener(ILabelListener aoListener) {
        moListeners.remove(aoListener);
    }

    /**
     *  Sends event to every listeners.
     *  @param  aoEvent event to be sent
     */
    protected void fireLabelEvent(LabelEvent aoEvent) {
        Iterator i = moListeners.iterator();
        while (i.hasNext()) {
            ILabelListener oListener = (ILabelListener)i.next();
            oListener.labelChanged(aoEvent);
        }
    }

}
