/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-01-22  Gelin   Initially created
 */

package ru.gelin.games.javatris.game;

import ru.gelin.games.javatris.ui.LabelEvent;
import ru.gelin.games.javatris.ui.ILabelModel;

import javax.swing.SwingConstants;

/**
 *  Wrapper for integer value which implements {@link ILabelModel}. Used for score, level and lines counters.
 */
public class Counter extends ALabelModel {

    /** wrapped integer value */
    protected int miValue;

    /**
     *  Default constructor.
     */
    public Counter() {
        super();
    }

    /**
     *  Constructor with integer argument. Sets wrapped integer value.
     *  @param  aiValue initial value
     */
    public Counter(int aiValue) {
        super();
        set(aiValue);
    }

    /**
     *  Gets wrapped integer value.
     */
    public int get() {
        return miValue;
    }

    /**
     *  Sets new wrapped integer value.
     *  @param  aiValue new integer value
     *  @return new just assigned value
     */
    public int set(int aiValue) {
        miValue = aiValue;
        LabelEvent oEvent = new LabelEvent(this, getText());
        fireLabelEvent(oEvent);
        return miValue;
    }

    /**
     *  Increments wrapped integer value.
     *  @return new just incremented value
     */
    public int inc() {
        return set(get() + 1);
    }

    /**
     *  Add specified integer to wrapped value.
     *  @param  aiSummand   summand for addition
     *  @return new wrapped value
     */
    public int add(int aiSummand) {
        return set(get() + aiSummand);
    }

    /**
     *  Returns text representation of wrapped integer for label.
     */
    public String getText() {
        return String.valueOf(miValue);
    }

    /**
     *  Returns text alignment of number.
     */
    public int getHorizontalAlignment() {
        return SwingConstants.RIGHT;
    }

}
