/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-05-26  Gelin   Initially created.
 */

package ru.gelin.games.javatris.game;

/**
 *  Interface for saver - implementation specific class which save game state and settings.
 */
public interface ISaver {

    /**
     *  Saves game settings. Game settings should be saved separately for different system user's.
     *  @param  aoSettings  game settings to be saved
     */
    void save(Settings aoSettings);

    /**
     *  Saves records list. Records should be saved globaly for all system.
     *  Also signature of records must be saved.
     *  @param  aoRecordsList   list of game records to be saved
     */
    void save(RecordsList aoRecordsList);

    /**
     *  Loads game settings. Settings of current system user should be restored.
     *  @param  aoSettings  game setting to which parameters will be restored
     */
    void load(Settings aoSettings);

    /**
     *  Loads records list. Global system wide records should be loaded. Records list
     *  signature should be checked, if it's invalid, saved records must be ignored.
     *  @param  aoRecordsList   list of game records to which saved records will be restored
     */
    void load(RecordsList aoRecordsList);

}
