/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-01-22  Gelin   Initially created
 */

package ru.gelin.games.javatris.game;

import ru.gelin.games.javatris.ui.LabelEvent;

/**
 *  <code>Counter</code> for game levels. Includes checking of assigned value.
 */
public class LevelCounter extends Counter implements IGameLevels {

    /**
     *  Default constructor. Sets minimum game level.
     */
    public LevelCounter() {
        super(MIN_LEVEL);
    }

    /**
     *  Constructor with integer argument. Sets defined game level.
     *  If specified level is less than <code>MIN_LEVEL</code>, <code>MIN_LEVEL</code> is set.
     *  If specified level is more than <code>MAX_LEVEL</code>, <code>MAX_LEVEL</code> is set.
     *  @param  aiValue initial value
     */
    public LevelCounter(int aiValue) {
        super(aiValue);
        set(aiValue);
    }

    /**
     *  Sets new game level.
     *  If specified level is less than <code>MIN_LEVEL</code>, <code>MIN_LEVEL</code> is set.
     *  If specified level is more than <code>MAX_LEVEL</code>, <code>MAX_LEVEL</code> is set.
     *  @param  aiValue new level value
     *  @return new just assigned value
     */
    public int set(int aiValue) {
        if (aiValue < MIN_LEVEL) {
            aiValue = MIN_LEVEL;
        }
        if (aiValue > MAX_LEVEL) {
            aiValue = MAX_LEVEL;
        }
        if (miValue != aiValue) {
            miValue = aiValue;
            LabelEvent oEvent = new LabelEvent(this, getText());
            fireLabelEvent(oEvent);
        }
        return miValue;
    }

}
