/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-11-08  Gelin   Initially created
 */

package ru.gelin.games.javatris.launch;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.util.Messages;
import ru.gelin.games.javatris.util.Images;
import ru.gelin.games.javatris.ui.ContentPane;
import ru.gelin.games.javatris.actions.IActionNames;

import javax.swing.JApplet;
import javax.swing.JFrame;
import javax.swing.JDialog;
import java.util.logging.Logger;
import java.util.logging.Level;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.ActionEvent;

/**
 *  Runs Javatris as applet.
 */
public class Applet extends JApplet {

    /** logger instance */
    static private Logger moLog = null;
    /** logger name */
    static private final String LOGGER_NAME = "ru.gelin.games.javatris.launch.Applet";
    /** default log level */
    static private final Level DEF_LOG_LEVEL = Level.WARNING;

    /** Messages instance */
    private static Messages moMsg = null;

    /** Images instance */
    private static Images moImg = null;

    /** Game instance */
    private Javatris moGame = null;

    /**
     *  Inits applet.
     */
    public void init() {
        //print header
        System.out.println("JAJI v." + Javatris.VERSION + "." + Javatris.BUILD + "  Copyright (C) 2005  Denis Nelubin aka Gelin");
        System.out.println("JAJI comes with ABSOLUTELY NO WARRANTY");
        System.out.println("This is free software, and you are welcome to redistribute it");
        System.out.println("under certain conditions. For details see LICENSE.txt.");
        System.out.println("");
        //create game
        moGame = new Javatris();
        //get logger
        moLog = Logger.getLogger(LOGGER_NAME);
        //init Messages
        moMsg = Messages.getInstance();
        //init Images
        moImg = Images.getInstance();
        //create GUI frame
        JFrame.setDefaultLookAndFeelDecorated(true);
        JDialog.setDefaultLookAndFeelDecorated(true);
        ContentPane oContent = new ContentPane(moGame);
        setContentPane(oContent);
        //pack();
        //show();
        //init keys
        addKeyListener(new MyKeyListener());
    }

    /**
     *  Resumes game after pause.
     */
    public void start() {
        moGame.resumeAuto();
    }

    /**
     *  Pauses game.
     */
    public void stop() {
        moGame.pauseAuto();
    }

    /**
     *  Handler for applet key events
     */
    private class MyKeyListener extends KeyAdapter {
        public void keyPressed(KeyEvent aoEvent) {
            System.out.println("keyPressed: " + aoEvent);
            moGame.getAction(IActionNames.ROTATE_ACTION).actionPerformed(null);
        }
    }
}
