/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-06  Gelin   Initially created
 *  2006-04-09  Gelin   Added pause game activity
 */

package ru.gelin.games.javatris.launch;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.util.Messages;
import ru.gelin.games.javatris.util.Images;
import ru.gelin.games.javatris.ui.ContentPane;

import javax.swing.JFrame;
import javax.swing.JDialog;
import javax.swing.ImageIcon;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.logging.Logger;
import java.util.logging.Level;

/**
 *  Runs Javatris as application.
 */
public class Application {

    /** logger instance */
    static private Logger moLog = null;
    /** logger name */
    static private final String LOGGER_NAME = "ru.gelin.games.javatris.launch.Application";
    /** default log level */
    static private final Level DEF_LOG_LEVEL = Level.WARNING;

    /** Messages instance */
    private static Messages moMsg = null;

    /** Images instance */
    private static Images moImg = null;

    /**
     *  Starts application.
     *
     *  @param  args    Command line arguments.
     */
    public static void main(String[] args) {
        //print header
        System.out.println("JAJI v." + Javatris.VERSION + "." + Javatris.BUILD + "  Copyright (C) 2005  Denis Nelubin aka Gelin");
        System.out.println("JAJI comes with ABSOLUTELY NO WARRANTY");
        System.out.println("This is free software, and you are welcome to redistribute it");
        System.out.println("under certain conditions. For details see LICENSE.txt.");
        System.out.println("");
        //create game
        Javatris oGame = new Javatris(new PreferencesSaver());
        //get logger
        moLog = Logger.getLogger(LOGGER_NAME);
        //init Messages
        moMsg = Messages.getInstance();
        //init Images
        moImg = Images.getInstance();
        //choose L&F here
        try {
            //UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
            //UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
            //UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel");
            //UIManager.setLookAndFeel("com.sun.java.swing.plaf.gtk.GTKLookAndFeel");
        } catch (Exception e) {
        }
        //create GUI frame
        JFrame.setDefaultLookAndFeelDecorated(true);
        JDialog.setDefaultLookAndFeelDecorated(true);
        JFrame oFrame = new JFrame(moMsg.get("frame.title"));
        ContentPane oContent = new ContentPane(oGame);
        ImageIcon oIcon = moImg.get("frame.icon");
        if (oIcon != null) {
            oFrame.setIconImage(oIcon.getImage());
        }
        oFrame.setContentPane(oContent);
        oFrame.setResizable(false);
        oFrame.addWindowListener(new GameWindowListener(oGame));
        oFrame.pack();
        oFrame.show();
    }

    /**
     *  Inner WindowListener class.
     */
    static class GameWindowListener extends WindowAdapter {

        /** game reference */
        private Javatris moGame;

        /**
         *  Creates windows listener from game reference.
         */
        public GameWindowListener(Javatris aoGame) {
            moGame = aoGame;
        }

        /**
         *  Saves game options and exits the application when window is closed.
         */
        public void windowClosing(WindowEvent e) {
            moGame.save();
            //exit the application
            System.exit(0);
        }

        /**
         *  Pauses the game when window is minimized.
         */
        public void windowIconified(WindowEvent e) {
            moGame.pauseAuto();
        }

        /**
         *  Resumes the game when window is normalized.
         */
        public void windowDeiconified(WindowEvent e) {
            moGame.resumeAuto();
        }

        /**
         *  Pauses the game when window is deactivated.
         */
        public void windowDeactivated(WindowEvent e) {
            moGame.pauseAuto();
        }

        /**
         *  Resumes the game when window is activated.
         */
        public void windowActivated(WindowEvent e) {
            moGame.resumeAuto();
        }

    }

}
