/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.util.Messages;
import ru.gelin.games.javatris.util.Images;
import ru.gelin.games.javatris.util.Resource;

import java.util.Iterator;
import java.util.logging.Logger;
import java.util.logging.Level;
import javax.swing.JPanel;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JScrollPane;
import javax.swing.BorderFactory;
import javax.swing.SwingConstants;
import java.awt.BorderLayout;
import java.awt.Font;
import java.io.UnsupportedEncodingException;

/**
 *  Implements ContentPane for About dialog.
 */
public class AboutContentPane extends JPanel {

    /** game instance */
    private Javatris moGame;

    /** messages instance */
    private Messages moMsg = Messages.getInstance();

    /** images instance */
    private Images moImg = Images.getInstance();

    /** tab definitions */
    private String[][] TABS = {
        { "about_dialog.license_tab.title", "/LICENSE.txt" },
        { "about_dialog.3rd_license_tab.title", "/THIRDPARTYLICENSE.txt" },
        { "about_dialog.notice_tab.title", "/NOTICE.txt" },
    };

    /** resources charset */
    private static final String RES_CHARSET = "US-ASCII";
    /** rows to display resource content */
    private static final int ROWS = 15;
    /** columns to display resource content */
    private static final int COLS = 80;
    /** how decrease font size in resource content tabs */
    private static final int FONT_SIZE_DECREASE = 2;

    /** logger name */
    static private final String LOGGER_NAME = "ru.gelin.games.javatris.ui.AboutContentPane";
    /** default log level */
    static private final Level DEF_LOG_LEVEL = Level.WARNING;
    /** logger instance */
    static private Logger moLog = Logger.getLogger(LOGGER_NAME);

    /**
     *  Constructs content pane with information about game.
     *  @param  aoGame  game for which pane is created
     */
    public AboutContentPane(Javatris aoGame) {
        //create panel
        super();
        setLayout(new BorderLayout());
        moGame = aoGame;
        //set basic properties
        setOpaque(true);
        //add about label
        JPanel oLabelPanel = new JPanel();
        oLabelPanel.add(new JLabel(moImg.get("about_dialog.big_icon")));
        oLabelPanel.add(new JLabel(moMsg.get("about_dialog.label", new String[] {moGame.VERSION, moGame.BUILD})));
        add(oLabelPanel, BorderLayout.NORTH);
        //create tabbed pane
        JTabbedPane oTabs = new JTabbedPane();
        for (int i = 0; i < TABS.length; i++) {
            addTab(oTabs, i);
        }
        add(oTabs, BorderLayout.CENTER);
    }

    /**
     *  Adds tab with lecense description.
     *  @param  aoTabPane   where to add tab
     *  @param  aiTab   index of tab description
     */
    private void addTab(JTabbedPane aoTabPane, int aiTab) {
        Resource oResource = new Resource(TABS[aiTab][1]);
        String sText = null;
        try {
            sText = oResource.getString(RES_CHARSET);
        } catch (UnsupportedEncodingException e) {
            moLog.logp(DEF_LOG_LEVEL, "AboutContentPane", "addTab",
                        "Charset '" + RES_CHARSET + "' is not supported.");
            throw new RuntimeException(e);  //this must never occured, so it's runtime error
        }
        if (sText != null) {
            JTextArea oText = new JTextArea(sText, ROWS, COLS);
            oText.setEditable(false);
            oText.setLineWrap(true);
            oText.setFont(formatFont(oText.getFont()));
            JScrollPane oScroll = new JScrollPane(oText);
            aoTabPane.add(moMsg.get(TABS[aiTab][0]), oScroll);
        }
    }

    /**
     *  Makes font monospace and changes it's size.
     *  Style of returned font is copyed from specified font, but font name
     *  is set to "Monospaced" and font size is decreased.
     *  @param  aoFont  font which must be changed
     *  @return changed font
     */
    private static Font formatFont(Font aoFont) {
        int iSize = aoFont.getSize();
        int iStyle = aoFont.getStyle();
        return new Font("Monospaced", iStyle, iSize - FONT_SIZE_DECREASE);
    }

}

