/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-29  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.util.Messages;
import ru.gelin.games.javatris.util.Images;
import ru.gelin.games.javatris.actions.IActionNames;

import javax.swing.JToolBar;
import javax.swing.JButton;
import javax.swing.JToggleButton;
import javax.swing.AbstractButton;
import javax.swing.ImageIcon;

/**
 *  Right pane with game information.
 */
public class ButtonsPane extends JToolBar implements IToolBarModes {

    /** game instance */
    private Javatris moGame;

    /** messages instance */
    private Messages moMsg;

    /** images instance */
    private Images moImg;

    /** new game button */
    private JButton moNewButton;

    /** setup button */
    private JButton moSetupButton;

    /** top10 button */
    private JButton moTop10Button;

    /** pause button */
    private JToggleButton moPauseButton;

    /** about button */
    private JButton moAboutButton;

    /** mode of buttons show */
    private int miShowMode = SHOW_SELECTIVE;

    /**
     *  Constructs top panel with buttons.
     *  @param  aoGame  game for which pane is created
     */
    public ButtonsPane(Javatris aoGame) {
        //create panel
        super();
        moGame = aoGame;
        moMsg = Messages.getInstance();
        moImg = Images.getInstance();
        //set basic properties
        setFloatable(false);
        //new game button
        moNewButton = new ToolBarButton(moGame.getAction(IActionNames.NEW_GAME_ACTION));
        add(moNewButton);
        //pause button
        moPauseButton = new ToggleToolBarButton(moGame.getAction(IActionNames.PAUSE_GAME_ACTION));
        add(moPauseButton);
        addSeparator();
        //setup button
        moSetupButton = new ToolBarButton(moGame.getAction(IActionNames.SETTINGS_ACTION));
        add(moSetupButton);
        addSeparator();
        //top10 button
        moTop10Button = new ToolBarButton(moGame.getAction(IActionNames.TOP10_ACTION));
        add(moTop10Button);
        //about button
        moAboutButton = new ToolBarButton(moGame.getAction(IActionNames.ABOUT_ACTION));
        add(moAboutButton);
    }

    /**
     *  Sets button's icon, text and tooltip.
     *  If both icon and text are present, both are set.
     *  If only image or text is present, image or text is set.
     *  If no image and no text, exact value of <code>asText</code>
     *  is set as text of button.
     *
     *  @param  aoButton    button, which params will be set
     *  @param  asText      key of message with button's text
     *  @param  asIcon      key of image
     *  @param  asToolTip   key of message with tooltip text
     *  @param  abShowText  <code>true</code> if button must show text
     *                      in <code>SHOW_SELECTIVE</code> mode
     *  @see    Messages
     *  @see    Images
     *  @see    IToolBarModes
     */
    private void prepareButton(AbstractButton aoButton, String asText,
            String asIcon, String asToolTip, boolean abShowText)
    {
        ImageIcon oIcon = moImg.get(asIcon);
        String sText = moMsg.get(asText);
        boolean textFound = !asText.equals(sText);
        String sToolTip = moMsg.get(asToolTip);
        if ((miShowMode == SHOW_TEXT_ONLY) ||
                miShowMode == SHOW_ICON_AND_TEXT ||
                ((miShowMode == SHOW_SELECTIVE) && abShowText)) {    //must show in selective mode
            if (oIcon == null && textFound == false) {
                aoButton.setText(asText);
            } else if (textFound == true) {
                aoButton.setText(sText);
            }
        }
        if ((miShowMode == SHOW_ICON_ONLY) ||
                (miShowMode == SHOW_ICON_AND_TEXT) ||
                (miShowMode == SHOW_SELECTIVE)) {
            aoButton.setIcon(oIcon);
        }
        aoButton.setToolTipText(sToolTip);
        //aoButton.setMargin(new Insets(0, 0, 0, 0));
        aoButton.setFocusable(false);
    }

}
