/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-24  Gelin   Initially created.
 */

package ru.gelin.games.javatris.ui;

import java.util.EventObject;
import java.awt.Rectangle;

/**
 *  Simple event for changes in color table.
 *
 *  @see    IColorTableListener
 *  @see    IColorTableModel
 */
public class ColorTableEvent extends EventObject {

    /** rectangle (in cells) which must be repainted */
    private Rectangle moRepaintRect;

    /**
     *  Public constructor.
     *  @param  aoSource    source of event
     */
    public ColorTableEvent(Object aoSource) {
        super(aoSource);
    }

    /**
     *  Constructor with repaint rectangle.
     *  @param  aoSource    source of event
     *  @param  aoRepaintRect   rectangle (in cells) which must be repainted (was changed)
     */
    public ColorTableEvent(Object aoSource, Rectangle aoRepaintRect) {
        super(aoSource);
        moRepaintRect = aoRepaintRect;
    }

    /**
     *  Sets value of repaint rectangle.
     *  @param  aoRepaintRect   rectangle (in cells) which must be repainted
     */
    public void setRepaintRect(Rectangle aoRepaintRect) {
        moRepaintRect = aoRepaintRect;
    }

    /**
     *  Returns repaint rectangle.
     *  @return rectangle (in cells) which must be repainted
     */
    public Rectangle getRepaintRect() {
        return  moRepaintRect;
    }

}
