/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.util.Messages;

import java.awt.BorderLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JComponent;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.BorderFactory;
import javax.swing.JRootPane;

/**
 *  Common game dialog. It's modal dialog with custom content pane.
 */
public class CommonDialog extends JDialog {

    /** messages instance */
    private Messages moMsg = Messages.getInstance();

    /** general OK button */
    private JButton moOkButton;

    /**
     *  Constructs dialog.
     *  @param  asTitle title for dialog frame
     *  @param  aoContentPane   custom content pane for dialog
     */
    public CommonDialog(String asTitle, JComponent aoContentPane) {
        super((JFrame)null, asTitle, true); //modal dialog without parent
        JPanel oPanel = new JPanel(new BorderLayout());
        JPanel oBottomPanel = new JPanel();
        moOkButton = new JButton(moMsg.get("ok_button.text"));
        moOkButton.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    dispose();
                }
            } );
        //oBottomPanel.setBorder(BorderFactory.createEmptyBorder(EMPTY_BORDER_SIZE, 0, EMPTY_BORDER_SIZE, 0));
        oBottomPanel.add(moOkButton);
        oPanel.add(aoContentPane, BorderLayout.CENTER);
        oPanel.add(oBottomPanel, BorderLayout.SOUTH);
        setContentPane(oPanel);
        JRootPane oRoot = getRootPane();
        oRoot.setDefaultButton(moOkButton);
        oRoot.setWindowDecorationStyle(JRootPane.INFORMATION_DIALOG);
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);
    }

    /**
     *  Shows dialog. This method do all nessesary work, so you do not need to call pack() method.
     *  Just create dialog and show() it.
     */
    public void show() {
        pack();
        moOkButton.requestFocusInWindow();  //this method is overidded for this call can be possible
        super.show();
    }

}
