/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-11  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.actions.IActionNames;
import ru.gelin.games.javatris.actions.AKeyAction;

import java.util.Iterator;
import javax.swing.JPanel;
import javax.swing.JComponent;
import javax.swing.BorderFactory;
import java.awt.BorderLayout;

/**
 *  Implements ContentPane both for application and applet.
 */
public class ContentPane extends JPanel {

    /** game instance */
    protected Javatris moGame;

    /** inner empty border size */
    private static final int EMPTY_BORDER_SIZE = 5;

    /**
     *  Constructs main GUI for the game.
     *  @param  aoGame  game for which pane is created
     */
    public ContentPane(Javatris aoGame) {
        //create panel
        super(new BorderLayout());
        moGame = aoGame;
        //set basic properties
        setOpaque(true);
        setBorder(BorderFactory.createRaisedBevelBorder());
        //add Glass
        JComponent oGlass = new GlassPane(moGame);
        oGlass.setBorder(BorderFactory.createLoweredBevelBorder());
        oGlass.setDoubleBuffered(true);
        add(oGlass, BorderLayout.CENTER);
        //add info pane
        JComponent oInfoPane = new InfoPane(moGame);
        oInfoPane.setBorder(BorderFactory.createCompoundBorder(
                BorderFactory.createLoweredBevelBorder(),
                BorderFactory.createEmptyBorder(EMPTY_BORDER_SIZE,
                        EMPTY_BORDER_SIZE, EMPTY_BORDER_SIZE, EMPTY_BORDER_SIZE)));
        add(oInfoPane, BorderLayout.EAST);
        //add buttons pane
        JComponent oButtonsPane = new ButtonsPane(moGame);
        add(oButtonsPane, BorderLayout.NORTH);
        //register key actions
        Iterator i = moGame.getActions().iterator();
        while (i.hasNext()) {
            Object oAction = i.next();
            if (oAction instanceof AKeyAction) {
                ((AKeyAction)oAction).registerFor(this);
            }
        }
    }

}
