/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-28  Gelin   Initially created.
 *  2006-08-26  Gelin   Added mouse activity.
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.actions.IActionNames;

import java.awt.event.MouseEvent;
import javax.swing.event.MouseInputAdapter;

/**
 *  Shows game glass. Adds mouse activity to ColorTable.
 */
public class GlassPane extends ColorTable {

    private Javatris moGame;

    /**
     *  Public constructor.
     */
    public GlassPane(Javatris aoGame) {
        super(aoGame.getGlass());
        moGame = aoGame;
        MouseInputAdapter oListener = new GlassMouseListener();
        addMouseMotionListener(oListener);
        addMouseListener(oListener);
    }

    /**
     *  Class for detecting mouse events.
     */
    private class GlassMouseListener extends MouseInputAdapter {

        public void mouseMoved(MouseEvent e) {
            if (moGame.getSettings().isMouseEnabled()) {
                int x = e.getX();
                x = pixelsToCells(x);
                if (!moGame.isPaused() && !moGame.isBlockStopped()) {
                    moGame.getGlass().moveTo(x);
                }
            }
        }

        public void mouseDragged(MouseEvent e) {
            mouseMoved(e);
        }

        public void mouseClicked(MouseEvent e) {
            if (moGame.getSettings().isMouseEnabled()) {
                if (e.getButton() == moGame.getSettings().getDropMouseButton()) {
                    moGame.getAction(IActionNames.DROP_ACTION).actionPerformed(null);
                } else if (e.getButton() == moGame.getSettings().getRotateMouseButton()) {
                    moGame.getAction(IActionNames.ROTATE_ACTION).actionPerformed(null);
                }
            }
        }

        /**
         *  Converts X coordinate in pixels to X coordinate in cells.
         */
        private int pixelsToCells(int aiX) {
            int x = (aiX - miXShift) / miCellSize;
            if (x < 0) {
                x = 0;
            }
            return x;
        }

    }

}
