/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-24  Gelin   Initially created.
 */

package ru.gelin.games.javatris.ui;

import java.awt.Color;

/**
 *  Interface for color table model. Color table consists of square colored
 *  cells.
 */
public interface IColorTableModel {

    /**
     *  Returns color of specified cell.
     *  @param  aiX     X coordinate of specified cell
     *  @param  aiY     Y coordinate of specified cell
     *  @return color of specified cell
     */
    public Color getColor(int aiX, int aiY);

    /**
     *  Returns number of colums of table.
     *  @return number of columns
     */
    public int getWidth();

    /**
     *  Returns number of rows of table.
     *  @return  number of rows
     */
    public int getHeight();

    /**
     *  Returns preferred size (width and height) of each cell.
     *  Preferred size of component must be calculated according this value.
     *  @return preferred size of cell
     */
    public int getPreferredCellSize();

    /**
     *  Returns minimum size (width and height) of each cell.
     *  Minimum size of component must be calculated according this value.
     *  @return minimum size of cell
     */
    public int getMinimumCellSize();

    /**
     *  Returns maximum size (width and height) of each cell.
     *  Maximum size of component must be calculated according this value.
     *  @return maximum size of cell
     */
    public int getMaximumCellSize();

    /**
     *  Adds listener of changes in this model.
     *  @param  aoListener  new listener to add
     */
    public void addColorTableListener(IColorTableListener aoListener);

    /**
     *  Removes listener of changes in this model.
     *  @param  aoListener  listener to be removed
     */
    public void removeColorTableListener(IColorTableListener aoListener);

}