/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-26  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.util.Messages;

import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import java.awt.GridLayout;
import java.awt.Dimension;

/**
 *  Right pane with game information.
 */
public class InfoPane extends JPanel {

    /** game instance */
    private Javatris moGame;

    /** messages instance */
    private Messages moMsg;

    /** label shows game score */
    private JLabel moScoreLabel;

    /** label shows game lines */
    private JLabel moLinesLabel;

    /** label shows game level of complexity */
    private JLabel moLevelLabel;

    /** label shows best player's name */
    private JLabel moBestNameLabel;

    /** label shows best player's score */
    private JLabel moBestScoreLabel;

    /** zero label fill */
    private static String ZERO_SCORE = "0";

    /**
     *  Constructs right info panel.
     *  @param  aoGame  game for which pane is created
     */
    public InfoPane(Javatris aoGame) {
        //create panel
        super();
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        moGame = aoGame;
        moMsg = Messages.getInstance();
        //set basic properties
        setPreferredSize(new Dimension(180, 180));
        //panel with scores
        TitledPane oInfoPanel = new TitledPane(moMsg.get("info_border.title"));
        //score
        oInfoPanel.add(TitledPane.createLeftLabel(moMsg.get("score.label")),
                TitledPane.GRID_BAG_LEFT);
        moScoreLabel = TitledPane.createRightLabel(moGame.getScore());
        oInfoPanel.add(moScoreLabel, TitledPane.GRID_BAG_RIGHT);
        //lines
        oInfoPanel.add(TitledPane.createLeftLabel(moMsg.get("lines.label")),
                TitledPane.GRID_BAG_LEFT);
        moLinesLabel = TitledPane.createRightLabel(moGame.getLines());
        oInfoPanel.add(moLinesLabel, TitledPane.GRID_BAG_RIGHT);
        //level
        oInfoPanel.add(TitledPane.createLeftLabel(moMsg.get("level.label")),
                TitledPane.GRID_BAG_LEFT);
        moLevelLabel = TitledPane.createRightLabel(moGame.getLevel());
        oInfoPanel.add(moLevelLabel, TitledPane.GRID_BAG_RIGHT);
        add(oInfoPanel);
        //panel with preview of next block
        TitledPane oNextPanel = new TitledPane(moMsg.get("next_border.title"));
        oNextPanel.setLayout(new GridLayout(1, 1));
        ColorTable oNextBlock = new ColorTable(moGame.getNextBlockModel());
        oNextBlock.setBorder(BorderFactory.createLoweredBevelBorder());
        oNextPanel.add(oNextBlock);
        add(oNextPanel);
        //panel presented best player
        TitledPane oBestPanel = new TitledPane(moMsg.get("best_border.title"));
        //name
        oBestPanel.add(TitledPane.createLeftLabel(moMsg.get("best_name.label")),
                TitledPane.GRID_BAG_LEFT);
        moBestNameLabel = TitledPane.createRightLabel(moGame.getSettings().getRecords().getBestPlayerModel());
        //moBestNameLabel.setText("Anonymous");
        oBestPanel.add(moBestNameLabel, TitledPane.GRID_BAG_RIGHT);
        //score
        oBestPanel.add(TitledPane.createLeftLabel(moMsg.get("best_score.label")),
                TitledPane.GRID_BAG_LEFT);
        moBestScoreLabel = TitledPane.createRightLabel(moGame.getSettings().getRecords().getBestScoreModel());
        oBestPanel.add(moBestScoreLabel, TitledPane.GRID_BAG_RIGHT);
        add(oBestPanel);
    }

}
