/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-01-15  Gelin   Initially created.
 */

package ru.gelin.games.javatris.ui;

import javax.swing.JLabel;

/**
 *  Represents label with model. When model is changed label changes it's text too.
 *  @see    ILabelModel
 */
public class ModeledLabel extends JLabel implements ILabelListener {

    /** model */
    protected ILabelModel moModel;

    /**
     *  Public constructor.
     *  @param  aoModel model for label
     */
    public ModeledLabel(ILabelModel aoModel) {
        super();
        moModel = aoModel;
        moModel.addLabelListener(this);
        setText(moModel.getText());
        setHorizontalAlignment(moModel.getHorizontalAlignment());
    }

    /**
     *  Invokes when model changed.
     *  If event's <code>getText()</code> does not returns <code>null</code>, label's text is set to this value.
     *  Otherwise label's text and alignment is set according to model's values.
     */
    public void labelChanged(LabelEvent aoEvent) {
        if (aoEvent.getText() != null) {
            setText(aoEvent.getText());
        } else {
            setText(moModel.getText());
            setHorizontalAlignment(moModel.getHorizontalAlignment());
        }
    }

}
