/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2005-10-29  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import javax.swing.JPanel;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.BorderFactory;
import javax.swing.border.Border;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.Font;

/**
 *  Panel with titled border and GridBagLayout. Used in right info pane.
 */
public class TitledPane extends JPanel {

    /** placement constraints for left side labels */
    public static final GridBagConstraints GRID_BAG_LEFT;

    /** placement constraints for right side labels */
    public static final GridBagConstraints GRID_BAG_RIGHT;

    /** font size increase for right labels */
    private static final int FONT_SIZE_INCREASE = 4;

    /** inner empty border size */
    private static final int EMPTY_BORDER_SIZE = 5;

    /**
     *  Constructs this panel.
     *  @param  asTitle  title import java.awt.GridBagLayout;of panel
     */
    public TitledPane(String asTitle) {
        //create panel
        super(new GridBagLayout());
        //set basic properties
        //setPreferredSize(new Dimension(100, 100));
        Border oBorder = BorderFactory.createCompoundBorder(
                BorderFactory.createTitledBorder(asTitle),
                BorderFactory.createEmptyBorder(EMPTY_BORDER_SIZE,
                        EMPTY_BORDER_SIZE, EMPTY_BORDER_SIZE,EMPTY_BORDER_SIZE));
        setBorder(oBorder);

    }

    /**
     *  Adds component into container with GridBagLayout
     *
     *  @param  aoComponent component to add
     *  @param  aoConstraints   rules how to add component
     */
    public void add(JComponent aoComponent, GridBagConstraints aoConstraints) {
        GridBagLayout oLayout = (GridBagLayout)getLayout();
        oLayout.setConstraints(aoComponent, aoConstraints);
        add(aoComponent);
    }

    /**
     *  creates left label
     *
     *  @return new empty left label
     */
    public static JLabel createLeftLabel() {
        JLabel oLabel = new JLabel();
        oLabel.setHorizontalAlignment(JLabel.RIGHT);
        oLabel.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, EMPTY_BORDER_SIZE));
        return oLabel;
    }

    /**
     *  creates left label with initial text
     *
     *  @param  asText  initial label text
     *  @return new left label
     */
    public static JLabel createLeftLabel(String asText) {
        JLabel oLabel = createLeftLabel();
        oLabel.setText(asText);
        return oLabel;
    }

    /**
     *  creates right label
     *
     *  @return new empty right label
     */
    public static JLabel createRightLabel() {
        JLabel oLabel = new JLabel();
        oLabel.setFont(formatFont(oLabel.getFont()));
        oLabel.setBorder(BorderFactory.createLoweredBevelBorder());
        return oLabel;
    }

    /**
     *  Creates right label from label model
     *  @param  aoModel model for label creation
     *  @return new {@link ModeledLabel} created from <code>ILabelModel</code>
     */
    public static JLabel createRightLabel(ILabelModel aoModel) {
        JLabel oLabel = new ModeledLabel(aoModel);
        oLabel.setFont(formatFont(oLabel.getFont()));
        oLabel.setBorder(BorderFactory.createLoweredBevelBorder());
        return oLabel;
    }

    /**
     *  Changes font size and makes it bold.
     *  @param  aoFont  font which size must be changed
     *  @return changed font (for chain changes)
     */
    private static Font formatFont(Font aoFont) {
        int iSize = aoFont.getSize();
        int iStyle = aoFont.getStyle();
        return aoFont.deriveFont(iStyle | Font.BOLD, iSize + FONT_SIZE_INCREASE);
    }

    /**
     *  generates GridBagConstraints used in this panel
     */
    static {
        GRID_BAG_LEFT = new GridBagConstraints();
        GRID_BAG_LEFT.fill = GridBagConstraints.HORIZONTAL;
        GRID_BAG_RIGHT = new GridBagConstraints();
        GRID_BAG_RIGHT.fill = GridBagConstraints.HORIZONTAL;
        GRID_BAG_RIGHT.gridwidth = GridBagConstraints.REMAINDER;
        GRID_BAG_RIGHT.weightx = 1.0;
    }

}
