/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-09  Gelin   Initially created.
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.actions.AToggleToolBarAction;

import javax.swing.JToggleButton;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.AbstractButton;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeEvent;

/**
 *  Represents a toggle button changed a little for tool bars.
 */
public class ToggleToolBarButton extends JToggleButton {

    /**
     *  Public constructor.
     *  @param  aoAction    action for button creation.
     */
    public ToggleToolBarButton(Action aoAction) {
        super(aoAction);
        setFocusable(false);
    }

    /**
     *  This method addes to superclass'es reaction to change of "Selected" property.
     */
    protected void configurePropertiesFromAction(Action a) {
        super.configurePropertiesFromAction(a);
        Boolean oSelected = (Boolean)a.getValue(AToggleToolBarAction.SELECTED);
        boolean bSelected = oSelected != null ? oSelected.booleanValue() : false;
        setSelected(bSelected);
    }

    /**
     *  This method addes to superclass'es reaction to change of "Selected" property.
     */
    protected PropertyChangeListener createActionPropertyChangeListener(Action a) {
        return new ToggleButtonActionPropertyChangeListener(this);
    }

    /**
     *  This is toggle button property change listener.
     *  Most code gets from javax.swing.AbstractButton.ButtonActionPropertyChangeListener.
     */
    private static class ToggleButtonActionPropertyChangeListener implements PropertyChangeListener {

        /** button reference */
        private JToggleButton moButton;

        /**
         *  Creates listener for specified button.
         */
        public ToggleButtonActionPropertyChangeListener(JToggleButton aoButton) {
            moButton = aoButton;
        }

        /**
         *  Calls when property is changed.
         */
        public void propertyChange(PropertyChangeEvent e) {
            String propertyName = e.getPropertyName();
            AbstractButton button = moButton;
            if (button == null) {
                Action action = (Action)e.getSource();
                action.removePropertyChangeListener(this);
                } else {
                    if (e.getPropertyName().equals(Action.NAME)) {
                        Boolean hide = (Boolean)button.getClientProperty("hideActionText");
                        if (hide == null || hide == Boolean.FALSE) {
                            String text = (String) e.getNewValue();
                            button.setText(text);
                            button.repaint();
                        }
                    } else if (e.getPropertyName().equals(Action.SHORT_DESCRIPTION)) {
                        String text = (String) e.getNewValue();
                        button.setToolTipText(text);
                    } else if (propertyName.equals("enabled")) {
                        Boolean enabledState = (Boolean) e.getNewValue();
                        button.setEnabled(enabledState.booleanValue());
                        button.repaint();
                    } else if (e.getPropertyName().equals(Action.SMALL_ICON)) {
                        Icon icon = (Icon) e.getNewValue();
                        button.setIcon(icon);
                        button.invalidate();
                        button.repaint();
                    } else if (e.getPropertyName().equals(Action.MNEMONIC_KEY)) {
                        Integer mn = (Integer) e.getNewValue();
                        button.setMnemonic(mn.intValue());
                        button.invalidate();
                        button.repaint();
                    } else if (e.getPropertyName().equals(Action.ACTION_COMMAND_KEY)) {
                        button.setActionCommand((String)e.getNewValue());
                    } else if (e.getPropertyName().equals(AToggleToolBarAction.SELECTED)) {
                        Boolean oSelected = (Boolean)e.getNewValue();
                        boolean bSelected = oSelected != null ? oSelected.booleanValue() : false;
                        button.setSelected(bSelected);
                    }
                }
        }
    }

}
