/*
 *  JAJI - Just Another Javatris Implementation.
 *  Copyright (C) 2005  Denis Nelubin aka Gelin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  http://gelin.ru
 *  mailto:java@gelin.ru
 *
 *  2006-04-18  Gelin   Initially created
 */

package ru.gelin.games.javatris.ui;

import ru.gelin.games.javatris.game.Javatris;
import ru.gelin.games.javatris.game.RecordItem;
import ru.gelin.games.javatris.util.Messages;

import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.TableColumn;
import javax.swing.BorderFactory;
import java.awt.BorderLayout;
import java.util.Date;

/**
 *  Implements ContentPane for Top10 dialog.
 */
public class Top10ContentPane extends JPanel {

    /** game instance */
    private Javatris moGame;

    /** messages instance */
    private Messages moMsg = Messages.getInstance();

    /** column names */
    private final String[] COLUMNS = {
        moMsg.get("top10_table.rate_column.name"),
        moMsg.get("top10_table.player_column.name"),
        moMsg.get("top10_table.score_column.name"),
        moMsg.get("top10_table.date_column.name"),
    };

    /** columns width */
    private final int[] COLUMN_WIDTHS = {
        25,
        125,
        85,
        80,
    };

    /**
     *  Constructs content pane with information about game.
     *  @param  aoGame  game for which pane is created
     */
    public Top10ContentPane(Javatris aoGame) {
        //create panel
        super();
        setLayout(new BorderLayout());
        moGame = aoGame;
        //set basic properties
        setOpaque(true);
        //create records table
        JTable oTable = new JTable(new Top10TableModel());
        for (int i = 0; i < COLUMN_WIDTHS.length; i++) {
            TableColumn oColumn = oTable.getColumnModel().getColumn(i);
            oColumn.setPreferredWidth(COLUMN_WIDTHS[i]);
        }
        //add records table
        add(oTable.getTableHeader(), BorderLayout.NORTH);
        add(oTable, BorderLayout.CENTER);
        setBorder(BorderFactory.createLoweredBevelBorder());
    }

    /**
     *  This class provides values from game's records list
     *  to GUI table.
     */
    private class Top10TableModel extends AbstractTableModel {

        public int getColumnCount() {
            return COLUMNS.length;
        }

        public String getColumnName(int columnIndex) {
            return COLUMNS[columnIndex];
        }

        public int getRowCount() {
            return moGame.getSettings().getRecords().size();
        }

        public Object getValueAt(int rowIndex, int columnIndex) {
            Object oResult = null;
            RecordItem oRecord = moGame.getSettings().getRecords().get(rowIndex);
            switch (columnIndex) {
            case 0: //rate column
                oResult = new Integer(rowIndex + 1); //1-based index
                break;
            case 1: //player column
                oResult = oRecord.getName();
                break;
            case 2: //score column
                oResult = new Integer(oRecord.getScore());
                break;
            case 3: //date column
                oResult = oRecord.getDate();
                break;
            }
            return oResult;
        }

        public Class getColumnClass(int columnIndex) {
            Class oResult = String.class;
            switch (columnIndex) {
            case 0: //rate column
                oResult = Integer.class;
                break;
            case 1: //player column
                oResult = String.class;
                break;
            case 2: //score column
                oResult = Integer.class;
                break;
            case 3: //data column
                oResult = Date.class;
                break;
            }
            return oResult;
        }

    }

}

